using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Runtime.Remoting;
using System.Runtime.Remoting.Channels;
using System.Runtime.Remoting.Channels.Http;
using System.IO;
using RegularLanguages;

namespace RestartingAutomatonClient
{
    public partial class ClientForm : Form
    {
        public ClientForm()
        {
            InitializeComponent();
            this.StopServiceUI();
        }

        private RestartingAutomatonService service = null;

        private void StartServiceUI()
        {
            this.loactionTextBox.Enabled = false;
            this.runButton.Enabled = false;
            this.stopButton.Enabled = true;
            this.alphabetButton.Enabled = true;
            this.decideButton.Enabled = true;
            this.decideTextBox.Enabled = true;
            this.wordToAllButton.Enabled = true;
            this.wordToAllTextBox.Enabled = true;
            this.wordToWordButton.Enabled = true;
            this.wordToWordFromTextBox.Enabled = true;
            this.wordToWordToTextBox.Enabled = true;
            this.resultTextBox.Enabled = true;
        }

        private void StopServiceUI()
        {
            this.loactionTextBox.Enabled = true;
            this.runButton.Enabled = true;
            this.stopButton.Enabled = false;
            this.alphabetButton.Enabled = false;
            this.decideButton.Enabled = false;
            this.decideTextBox.Enabled = false;
            this.wordToAllButton.Enabled = false;
            this.wordToAllTextBox.Enabled = false;
            this.wordToWordButton.Enabled = false;
            this.wordToWordFromTextBox.Enabled = false;
            this.wordToWordToTextBox.Enabled = false;
            this.resultTextBox.Enabled = false;
        }

        private void runButton_Click(object sender, EventArgs e)
        {
            try
            {
                this.service = (RestartingAutomatonService)
                    Activator.GetObject(typeof(RestartingAutomatonService),
                        this.loactionTextBox.Text);
                this.StartServiceUI();
            }
            catch { MessageBox.Show("The service is unavailable.", "Warning"); }
        }

        private void stopButton_Click(object sender, EventArgs e)
        {
            this.service = null;
            this.StopServiceUI();
        }

        private void alphabetButton_Click(object sender, EventArgs e)
        {
            try
            {
                MessageBox.Show(this.service.GetAlphabet());
            }
            catch { MessageBox.Show("Unable to connect to the remote server.", "Error"); }
        }

        private void decideButton_Click(object sender, EventArgs e)
        {
            try
            {
                if (this.service.IsFromAlphabet(this.decideTextBox.Text))
                {
                    if (this.service.Decide(this.decideTextBox.Text))
                        MessageBox.Show("Accept", "Information");
                    else MessageBox.Show("Reject", "Information");
                }
                else MessageBox.Show("All the letters of the word must be from the alphabet.", "Warning");
            }
            catch { MessageBox.Show("Unable to connect to the remote server.", "Error"); }
        }

        private void wordToAllButton_Click(object sender, EventArgs e)
        {
            try
            {
                if (!this.service.IsFromAlphabet(this.wordToAllTextBox.Text))
                {
                    MessageBox.Show("All the letters of the from-word must be from the alphabet.", "Warning");
                    return;
                }
                this.resultTextBox.Text = this.service.WordToAll(this.wordToAllTextBox.Text);
            }
            catch { MessageBox.Show("Unable to connect to the remote server.", "Error"); }
        }

        private void wordToWordButton_Click(object sender, EventArgs e)
        {
            try
            {
                if (!this.service.IsFromAlphabet(this.wordToWordFromTextBox.Text))
                {
                    MessageBox.Show("All the letters of the from-word must be from the alphabet.", "Warning");
                    return;
                }
                if (!this.service.IsFromAlphabet(this.wordToWordToTextBox.Text))
                {
                    MessageBox.Show("All the letters of the to-word must be from the alphabet.", "Warning");
                    return;
                }
                this.resultTextBox.Text = this.service.WordToWord(
                    this.wordToWordFromTextBox.Text, this.wordToWordToTextBox.Text);
            }
            catch { MessageBox.Show("Unable to connect to the remote server.", "Error"); }
        }
    }
}